@@ -9,35 +9,28 @@ use crate::error::{
 	Error as AppError,
 	Result,
 };
-use git2::Commit as GitCommit;
-use git_conventional::Commit as ConventionalCommit;
+use git2::{
+	Commit as GitCommit,
+	Signature as CommitSignature,
+};
+use git_conventional::{
+	Commit as ConventionalCommit,
+	Footer as ConventionalFooter,
+};
+use lazy_regex::{
+	lazy_regex,
+	Lazy,
+	Regex,
+};
 use serde::ser::{
 	Serialize,
 	SerializeStruct,
 	Serializer,
 };
 
-/// Common commit object that is parsed from a repository.
-#[derive(Debug, Clone, PartialEq, serde::Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct Commit<'a> {
-	/// Commit ID.
-	pub id:            String,
-	/// Commit message including title, description and summary.
-	pub message:       String,
-	/// Conventional commit.
-	#[serde(skip_deserializing)]
-	pub conv:          Option<ConventionalCommit<'a>>,
-	/// Commit group based on a commit parser or its conventional type.
-	pub group:         Option<String>,
-	/// Default commit scope based on (inherited from) conventional type or a
-	/// commit parser.
-	pub default_scope: Option<String>,
-	/// Commit scope for overriding the default one.
-	pub scope:         Option<String>,
-	/// A list of links found in the commit
-	pub links:         Vec<Link>,
-}
+/// Regular expression for matching SHA1 and a following commit message
+/// separated by a whitespace.
+static SHA1_REGEX: Lazy<Regex> = lazy_regex!(r#"^\b([a-f0-9]{40})\b (.*)$"#);
 
 /// Object representing a link
 #[derive(Debug, Clone, Eq, PartialEq, serde::Deserialize, serde::Serialize)]
@@ -67,8 +60,8 @@ struct Footer<'a> {
 	breaking:  bool,
 }
 
-impl<'a> From<&'a git_conventional::Footer<'a>> for Footer<'a> {
-	fn from(footer: &'a git_conventional::Footer<'a>) -> Self {
+impl<'a> From<&'a ConventionalFooter<'a>> for Footer<'a> {
+	fn from(footer: &'a ConventionalFooter<'a>) -> Self {
 		Self {
 			token:     footer.token().as_str(),
 			separator: footer.separator().as_str(),
@@ -78,12 +71,86 @@ impl<'a> From<&'a git_conventional::Footer<'a>> for Footer<'a> {
 	}
 }
 
+/// Commit signature that indicates authorship.
+#[derive(
+	Debug, Default, Clone, Eq, PartialEq, serde::Deserialize, serde::Serialize,
+)]
+pub struct Signature {
+	/// Name on the signature.
+	name:      Option<String>,
+	/// Email on the signature.
+	email:     Option<String>,
+	/// Time of the signature.
+	timestamp: i64,
+}
+
+impl<'a> From<CommitSignature<'a>> for Signature {
+	fn from(signature: CommitSignature<'a>) -> Self {
+		Self {
+			name:      signature.name().map(String::from),
+			email:     signature.email().map(String::from),
+			timestamp: signature.when().seconds(),
+		}
+	}
+}
+
+/// Common commit object that is parsed from a repository.
+#[derive(Debug, Default, Clone, PartialEq, serde::Deserialize)]
+#[serde(rename_all = "camelCase")]
+pub struct Commit<'a> {
+	/// Commit ID.
+	pub id:            String,
+	/// Commit message including title, description and summary.
+	pub message:       String,
+	/// Conventional commit.
+	#[serde(skip_deserializing)]
+	pub conv:          Option<ConventionalCommit<'a>>,
+	/// Commit group based on a commit parser or its conventional type.
+	pub group:         Option<String>,
+	/// Default commit scope based on (inherited from) conventional type or a
+	/// commit parser.
+	pub default_scope: Option<String>,
+	/// Commit scope for overriding the default one.
+	pub scope:         Option<String>,
+	/// A list of links found in the commit
+	pub links:         Vec<Link>,
+	/// Commit author.
+	pub author:        Signature,
+	/// Committer.
+	pub committer:     Signature,
+}
+
+impl<'a> From<String> for Commit<'a> {
+	fn from(message: String) -> Self {
+		if let Some(captures) = SHA1_REGEX.captures(&message) {
+			if let (Some(id), Some(message)) = (
+				captures.get(1).map(|v| v.as_str()),
+				captures.get(2).map(|v| v.as_str()),
+			) {
+				return Commit {
+					id: id.to_string(),
+					message: message.to_string(),
+					..Default::default()
+				};
+			}
+		}
+		Commit {
+			id: String::new(),
+			message,
+			..Default::default()
+		}
+	}
+}
+
 impl<'a> From<&GitCommit<'a>> for Commit<'a> {
 	fn from(commit: &GitCommit<'a>) -> Self {
-		Self::new(
-			commit.id().to_string(),
-			commit.message().unwrap_or_default().to_string(),
-		)
+		Commit {
+			id: commit.id().to_string(),
+			message: commit.message().unwrap_or_default().to_string(),
+			author: commit.author().into(),
+			committer: commit.committer().into(),
+			..Default::default()
+		}
 	}
 }
 
@@ -93,11 +160,7 @@ impl Commit<'_> {
 		Self {
 			id,
 			message,
-			conv: None,
-			group: None,
-			default_scope: None,
-			scope: None,
-			links: vec![],
+			..Default::default()
 		}
 	}
 
@@ -305,6 +368,8 @@ impl Serialize for Commit<'_> {
 			}
 		}
 		commit.serialize_field("links", &self.links)?;
+		commit.serialize_field("author", &self.author)?;
+		commit.serialize_field("committer", &self.committer)?;
 		commit.serialize_field("conventional", &self.conv.is_some())?;
 		commit.end()
 	}
@@ -315,7 +380,7 @@ mod test {
 	use super::*;
 	use regex::Regex;
 	#[test]
-	fn conventional_commit() {
+	fn conventional_commit() -> Result<()> {
 		let test_cases = vec![
 			(
 				Commit::new(
@@ -332,23 +397,20 @@ mod test {
 		for (commit, is_conventional) in &test_cases {
 			assert_eq!(is_conventional, &commit.clone().into_conventional().is_ok())
 		}
-		let commit = test_cases[0]
-			.0
-			.clone()
-			.parse(
-				&[CommitParser {
-					message:       Regex::new("test*").ok(),
-					body:          None,
-					group:         Some(String::from("test_group")),
-					default_scope: Some(String::from("test_scope")),
-					scope:         None,
-					skip:          None,
-				}],
-				false,
-			)
-			.unwrap();
+		let commit = test_cases[0].0.clone().parse(
+			&[CommitParser {
+				message:       Regex::new("test*").ok(),
+				body:          None,
+				group:         Some(String::from("test_group")),
+				default_scope: Some(String::from("test_scope")),
+				scope:         None,
+				skip:          None,
+			}],
+			false,
+		)?;
 		assert_eq!(Some(String::from("test_group")), commit.group);
 		assert_eq!(Some(String::from("test_scope")), commit.default_scope);
+		Ok(())
 	}
 
 	#[test]
@@ -404,7 +466,7 @@ mod test {
 	}
 
 	#[test]
-	fn parse_link() {
+	fn parse_link() -> Result<()> {
 		let test_cases = vec![
 			(
 				Commit::new(
@@ -430,20 +492,18 @@ mod test {
 			String::from("123123"),
 			String::from("test(commit): add test\n\nImlement RFC456\n\nFixes: #455"),
 		);
-		let commit = commit
-			.parse_links(&[
-				LinkParser {
-					pattern: Regex::new("RFC(\\d+)").unwrap(),
-					href:    String::from("rfc://$1"),
-					text:    None,
-				},
-				LinkParser {
-					pattern: Regex::new("#(\\d+)").unwrap(),
-					href:    String::from("https://github.com/$1"),
-					text:    None,
-				},
-			])
-			.unwrap();
+		let commit = commit.parse_links(&[
+			LinkParser {
+				pattern: Regex::new("RFC(\\d+)")?,
+				href:    String::from("rfc://$1"),
+				text:    None,
+			},
+			LinkParser {
+				pattern: Regex::new("#(\\d+)")?,
+				href:    String::from("https://github.com/$1"),
+				text:    None,
+			},
+		])?;
 		assert_eq!(
 			vec![
 				Link {
@@ -457,5 +517,39 @@ mod test {
 			],
 			commit.links
 		);
+		Ok(())
+	}
+
+	#[test]
+	fn parse_commit() {
+		assert_eq!(
+			Commit::new(String::new(), String::from("test: no sha1 given")),
+			Commit::from(String::from("test: no sha1 given"))
+		);
+		assert_eq!(
+			Commit::new(
+				String::from("8f55e69eba6e6ce811ace32bd84cc82215673cb6"),
+				String::from("feat: do something")
+			),
+			Commit::from(String::from(
+				"8f55e69eba6e6ce811ace32bd84cc82215673cb6 feat: do something"
+			))
+		);
+		assert_eq!(
+			Commit::new(
+				String::from("3bdd0e690c4cd5bd00e5201cc8ef3ce3fb235853"),
+				String::from("chore: do something")
+			),
+			Commit::from(String::from(
+				"3bdd0e690c4cd5bd00e5201cc8ef3ce3fb235853 chore: do something"
+			))
+		);
+		assert_eq!(
+			Commit::new(
+				String::new(),
+				String::from("thisisinvalidsha1 style: add formatting")
+			),
+			Commit::from(String::from("thisisinvalidsha1 style: add formatting"))
+		);
 	}
 }
