@@ -30,8 +30,31 @@ use std::fs::{
 };
 use std::io;
 
+/// Checks for a new version on crates.io
+#[cfg(feature = "update-informer")]
+fn check_new_version() {
+	use update_informer::Check;
+	let pkg_name = env!("CARGO_PKG_NAME");
+	let pkg_version = env!("CARGO_PKG_VERSION");
+	let informer = update_informer::new(
+		update_informer::registry::Crates,
+		pkg_name,
+		pkg_version,
+	);
+	if let Some(new_version) = informer.check_version().ok().flatten() {
+		log::info!(
+			"A new version of {pkg_name} is available: v{pkg_version} -> \
+			 {new_version}",
+		);
+	}
+}
+
 /// Runs `git-cliff`.
 pub fn run(mut args: Opt) -> Result<()> {
+	// Check if there is a new version available.
+	#[cfg(feature = "update-informer")]
+	check_new_version();
+
 	// Create the configuration file if init flag is given.
 	if args.init {
 		info!("Saving the configuration file to {:?}", DEFAULT_CONFIG);
@@ -40,7 +63,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 	}
 
 	// Set the working directory.
-	if let Some(workdir) = args.workdir {
+	if let Some(ref workdir) = args.workdir {
 		args.config = workdir.join(args.config);
 		args.repository = match args.repository {
 			Some(repository) => Some(workdir.join(repository)),
@@ -65,13 +88,15 @@ pub fn run(mut args: Opt) -> Result<()> {
 	let mut config = if path.exists() {
 		Config::parse(&path)?
 	} else {
-		warn!(
-			"{:?} is not found, using the default configuration.",
-			args.config
-		);
+		if !args.context {
+			warn!(
+				"{:?} is not found, using the default configuration.",
+				args.config
+			);
+		}
 		EmbeddedConfig::parse()?
 	};
-	if config.changelog.body.is_none() {
+	if config.changelog.body.is_none() && !args.context {
 		warn!("Changelog body is not specified, using the default template.");
 		config.changelog.body = EmbeddedConfig::parse()?.changelog.body;
 	}
@@ -92,14 +117,14 @@ pub fn run(mut args: Opt) -> Result<()> {
 	}
 	if args.prepend.is_some() {
 		config.changelog.footer = None;
-		if !(args.unreleased || args.latest) {
+		if !(args.unreleased || args.latest || args.range.is_some()) {
 			return Err(Error::ArgumentError(String::from(
 				"'-u' or '-l' is not specified",
 			)));
 		}
 	}
 	if args.body.is_some() {
-		config.changelog.body = args.body;
+		config.changelog.body = args.body.clone();
 	}
 	if args.sort == Sort::Oldest {
 		if let Some(ref sort_commits) = config.git.sort_commits {
@@ -115,7 +140,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 
 	// Initialize the git repository.
 	let repository =
-		Repository::init(args.repository.unwrap_or(env::current_dir()?))?;
+		Repository::init(args.repository.clone().unwrap_or(env::current_dir()?))?;
 
 	// Parse tags.
 	let mut tags = repository.tags(&config.git.tag_pattern, args.date_order)?;
@@ -148,6 +173,10 @@ pub fn run(mut args: Opt) -> Result<()> {
 		})
 		.collect();
 
+	// Print debug information about configuration and arguments.
+	log::trace!("{:#?}", args);
+	log::trace!("{:#?}", config);
+
 	// Parse commits.
 	let mut commit_range = args.range;
 	if args.unreleased {
@@ -232,10 +261,8 @@ pub fn run(mut args: Opt) -> Result<()> {
 	// Add custom commit messages to the latest release.
 	if let Some(custom_commits) = args.with_commit {
 		if let Some(latest_release) = releases.iter_mut().last() {
-			custom_commits.iter().for_each(|commit_message| {
-				latest_release
-					.commits
-					.push(Commit::new(String::new(), commit_message.to_string()))
+			custom_commits.into_iter().for_each(|message| {
+				latest_release.commits.push(Commit::from(message))
 			});
 		}
 	}
@@ -259,7 +286,14 @@ pub fn run(mut args: Opt) -> Result<()> {
 	if let Some(path) = args.prepend {
 		changelog.prepend(fs::read_to_string(&path)?, &mut File::create(path)?)
 	} else if let Some(path) = args.output {
-		changelog.generate(&mut File::create(path)?)
+		let mut output = File::create(path)?;
+		if args.context {
+			changelog.write_context(&mut output)
+		} else {
+			changelog.generate(&mut output)
+		}
+	} else if args.context {
+		changelog.write_context(&mut io::stdout())
 	} else {
 		changelog.generate(&mut io::stdout())
 	}
